# -*- coding:utf-8 -*-
"""
@author:bbw
@file:setup.py.py
@time:2017/10/9  10:26
"""
from distutils.core import setup

setup(
    name = '1nester',
    version ='1.3.0',
    py_modules = ['nester'],
    author = 'bbw',
    author_email = '313456923@qq.com',
    url = 'http://www.headfirstlabs.com',
    description = 'a simple printer of nested lists',
    )